.. highlight:: shell

============
Installation
============


Stable release
--------------

To install mixsea, run this command in your terminal:

.. code-block:: console

    $ pip install mixsea

This is the preferred method to install mixsea, as it will always install the
most recent stable release.

From sources
------------

The sources for mixsea can be downloaded from the `Github repo`_.

You can clone the public repository:

.. code-block:: console

    $ git clone https://github.com/modscripps/mixsea.git

Once you have a copy of the source, you can install it using pip. First change into the package directory:

.. code-block:: console

    $ cd mixsea

Then install either as a regular package

.. code-block:: console

    $ pip install .

or in developer mode (to immediately apply changes you make to the source code):

.. code-block:: console

    $ pip install -e .



.. _Github repo: https://github.com/modscripps/mixsea
.. _tarball: https://github.com/modscripps/mixsea/tarball/main
